<?php
/**
 * Modifies the user query for the ImagePress member directory.
 *
 * This function is a callback for the 'pre_user_query' action and modifies the user query
 * to include only users who have published posts in the ImagePress post type. It replaces
 * the default query condition 'post_type = post' with a condition that includes the ImagePress
 * post type specified in the plugin settings.
 *
 * @param WP_User_Query $args The user query arguments.
 */
function imagepress_member_directory_user_query( $args ) {
    $imagepress_slug  = imagepress_get_option( 'ip_slug' );
    $args->query_from = str_replace( 'post_type = post AND', "post_type IN ('$imagepress_slug') AND ", $args->query_from );
}



/**
 * Generates a member directory element for the ImagePress plugin.
 *
 * This function retrieves a list of members from the WordPress database and generates an HTML element
 * containing links to each member's profile page. The member list is ordered by post count and filtered
 * to include only authors who have published posts in public post types.
 *
 * @return string The generated HTML element containing the member directory.
 */
function imagepress_element_member_directory() {
    return '';
    global $wpdb;

    $out = '';

    $query   = "SELECT id, display_name FROM {$wpdb->prefix}users";
    $members = $wpdb->get_results( $query );

    add_action( 'pre_user_query', 'imagepress_member_directory_user_query' );

    $members = get_users(
        [
            'fields'              => [
                'ID',
                'display_name',
            ],
            'orderby'             => 'post_count',
            'who'                 => 'authors',
            'has_published_posts' => get_post_types(
                [
                    'public' => true,
                ]
            ),
        ]
    );

    remove_action( 'pre_user_query', 'imagepress_member_directory_user_query' );

    $ip_profile_page_id  = (int) imagepress_get_option( 'ip_profile_page' );
    $ip_profile_page_uri = get_permalink( $ip_profile_page_id );
    $ip_profile_slug     = (string) imagepress_get_option( 'cinnamon_author_slug' );

    $out .= '<ul class="ip-element-member-directory">';

    foreach ( $members as $group ) {
        $ip_profile_uri = $ip_profile_page_uri . '?' . $ip_profile_slug . '=' . get_the_author_meta( 'user_login', $group->ID );

        $out .= '<li><a href="' . $ip_profile_uri . '">' . $group->display_name . '</a></li>';
    }

    $out .= '</ul>';

    return $out;
}

add_shortcode( 'imagepress-member-directory', 'imagepress_element_member_directory' );



/**
 * Update last login user meta
 *
 * @param mixed $user_login
 * @param mixed $user
 * @return void
 */
function imagepress_update_last_login( $user_login, $user ) {
    update_user_meta( $user->ID, 'imagepress_last_login', current_time( 'mysql' ) );

    if ( (int) get_option( 'cinnamon_redirect_page' ) > 0 ) {
        $redirect_url = get_permalink( get_option( 'cinnamon_redirect_page' ) );

        // Redirect the user to the custom page after login
        wp_redirect( $redirect_url );

        exit;
    }
}

add_action( 'wp_login', 'imagepress_update_last_login', 10, 2 );



/**
 * Restrict access to the dashboard for non-admin users
 *
 * @return void
 */
function imagepress_restrict_non_admin() {
    if ( (int) get_option( 'cinnamon_hide_dashboard' ) > 0 && (int) get_option( 'cinnamon_redirect_page' ) > 0 ) {
        // Check if the current user is not an administrator
        if ( ! current_user_can( 'manage_options' ) && ! defined( 'DOING_AJAX' ) ) {
            $redirect_url = get_permalink( get_option( 'cinnamon_redirect_page' ) );

            // Redirect non-admin users to the custom page
            wp_redirect( $redirect_url );

            exit;
        }
    }
}

add_action( 'admin_init', 'imagepress_restrict_non_admin' );
